==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/KeyVaultSigningKeyParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the parameters for using a user's KeyVault for URL Signing Key.
 * @property resourceGroupName Resource group of the user's Key Vault containing the secret
 * @property secretName The name of secret in Key Vault.
 * @property secretVersion The version(GUID) of secret in Key Vault.
 * @property subscriptionId Subscription Id of the user's Key Vault containing the secret
 * @property typeName
 * @property vaultName The name of the user's Key Vault containing the secret
 */
public data class KeyVaultSigningKeyParametersArgs(
    public val resourceGroupName: Output<String>,
    public val secretName: Output<String>,
    public val secretVersion: Output<String>,
    public val subscriptionId: Output<String>,
    public val typeName: Output<String>,
    public val vaultName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs =
        com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs.builder()
            .resourceGroupName(resourceGroupName.applyValue({ args0 -> args0 }))
            .secretName(secretName.applyValue({ args0 -> args0 }))
            .secretVersion(secretVersion.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId.applyValue({ args0 -> args0 }))
            .typeName(typeName.applyValue({ args0 -> args0 }))
            .vaultName(vaultName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultSigningKeyParametersArgs].
 */
@PulumiTagMarker
public class KeyVaultSigningKeyParametersArgsBuilder internal constructor() {
    private var resourceGroupName: Output<String>? = null

    private var secretName: Output<String>? = null

    private var secretVersion: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var typeName: Output<String>? = null

    private var vaultName: Output<String>? = null

    /**
     * @param value Resource group of the user's Key Vault containing the secret
     */
    @JvmName("qhboyxtftlpkmvwr")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of secret in Key Vault.
     */
    @JvmName("sowvbjelguvvddge")
    public suspend fun secretName(`value`: Output<String>) {
        this.secretName = value
    }

    /**
     * @param value The version(GUID) of secret in Key Vault.
     */
    @JvmName("jcfwdvkrjnpxmowr")
    public suspend fun secretVersion(`value`: Output<String>) {
        this.secretVersion = value
    }

    /**
     * @param value Subscription Id of the user's Key Vault containing the secret
     */
    @JvmName("rdadtxvppiwofxfc")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value
     */
    @JvmName("bakwgsyyeecglfwg")
    public suspend fun typeName(`value`: Output<String>) {
        this.typeName = value
    }

    /**
     * @param value The name of the user's Key Vault containing the secret
     */
    @JvmName("ibjeuffvmiqsdccu")
    public suspend fun vaultName(`value`: Output<String>) {
        this.vaultName = value
    }

    /**
     * @param value Resource group of the user's Key Vault containing the secret
     */
    @JvmName("aiqryhtpemfwghtv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of secret in Key Vault.
     */
    @JvmName("erkntkookvovqbyp")
    public suspend fun secretName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretName = mapped
    }

    /**
     * @param value The version(GUID) of secret in Key Vault.
     */
    @JvmName("iruvecibuhhcscfl")
    public suspend fun secretVersion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretVersion = mapped
    }

    /**
     * @param value Subscription Id of the user's Key Vault containing the secret
     */
    @JvmName("okcankwoluvxiixr")
    public suspend fun subscriptionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value
     */
    @JvmName("hpirmjabwmyfhgps")
    public suspend fun typeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.typeName = mapped
    }

    /**
     * @param value The name of the user's Key Vault containing the secret
     */
    @JvmName("enacrhmngqhhykgs")
    public suspend fun vaultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultName = mapped
    }

    internal fun build(): KeyVaultSigningKeyParametersArgs = KeyVaultSigningKeyParametersArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        secretName = secretName ?: throw PulumiNullFieldException("secretName"),
        secretVersion = secretVersion ?: throw PulumiNullFieldException("secretVersion"),
        subscriptionId = subscriptionId ?: throw PulumiNullFieldException("subscriptionId"),
        typeName = typeName ?: throw PulumiNullFieldException("typeName"),
        vaultName = vaultName ?: throw PulumiNullFieldException("vaultName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/KeyVaultSigningKeyParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the parameters for using a user's KeyVault for URL Signing Key.
 * @property resourceGroupName Resource group of the user's Key Vault containing the secret
 * @property secretName The name of secret in Key Vault.
 * @property secretVersion The version(GUID) of secret in Key Vault.
 * @property subscriptionId Subscription Id of the user's Key Vault containing the secret
 * @property typeName
 * @property vaultName The name of the user's Key Vault containing the secret
 */
public data class KeyVaultSigningKeyParametersArgs(
    public val resourceGroupName: Output<String>,
    public val secretName: Output<String>,
    public val secretVersion: Output<String>,
    public val subscriptionId: Output<String>,
    public val typeName: Output<String>,
    public val vaultName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs =
        com.pulumi.azurenative.cdn.inputs.KeyVaultSigningKeyParametersArgs.builder()
            .resourceGroupName(resourceGroupName.applyValue({ args0 -> args0 }))
            .secretName(secretName.applyValue({ args0 -> args0 }))
            .secretVersion(secretVersion.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId.applyValue({ args0 -> args0 }))
            .typeName(typeName.applyValue({ args0 -> args0 }))
            .vaultName(vaultName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultSigningKeyParametersArgs].
 */
@PulumiTagMarker
public class KeyVaultSigningKeyParametersArgsBuilder internal constructor() {
    private var resourceGroupName: Output<String>? = null

    private var secretName: Output<String>? = null

    private var secretVersion: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var typeName: Output<String>? = null

    private var vaultName: Output<String>? = null

    /**
     * @param value Resource group of the user's Key Vault containing the secret
     */
    @JvmName("dfdcxywoibjymsex")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of secret in Key Vault.
     */
    @JvmName("ibjpbtwnbwbakysd")
    public suspend fun secretName(`value`: Output<String>) {
        this.secretName = value
    }

    /**
     * @param value The version(GUID) of secret in Key Vault.
     */
    @JvmName("okxqtunhqnpnqatv")
    public suspend fun secretVersion(`value`: Output<String>) {
        this.secretVersion = value
    }

    /**
     * @param value Subscription Id of the user's Key Vault containing the secret
     */
    @JvmName("etnpojuqjtnbhawa")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value
     */
    @JvmName("bboisuklwbgqwfja")
    public suspend fun typeName(`value`: Output<String>) {
        this.typeName = value
    }

    /**
     * @param value The name of the user's Key Vault containing the secret
     */
    @JvmName("epmgnltsxofemwlw")
    public suspend fun vaultName(`value`: Output<String>) {
        this.vaultName = value
    }

    /**
     * @param value Resource group of the user's Key Vault containing the secret
     */
    @JvmName("gqoypktrjvftpugd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of secret in Key Vault.
     */
    @JvmName("vycthwiekmhctcms")
    public suspend fun secretName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretName = mapped
    }

    /**
     * @param value The version(GUID) of secret in Key Vault.
     */
    @JvmName("ktvlrwyguimrvtle")
    public suspend fun secretVersion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secretVersion = mapped
    }

    /**
     * @param value Subscription Id of the user's Key Vault containing the secret
     */
    @JvmName("fcdkqkmqcromfxpj")
    public suspend fun subscriptionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value
     */
    @JvmName("ucsvclgvnrbmgjks")
    public suspend fun typeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.typeName = mapped
    }

    /**
     * @param value The name of the user's Key Vault containing the secret
     */
    @JvmName("cmfvnkusjehgledl")
    public suspend fun vaultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultName = mapped
    }

    internal fun build(): KeyVaultSigningKeyParametersArgs = KeyVaultSigningKeyParametersArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        secretName = secretName ?: throw PulumiNullFieldException("secretName"),
        secretVersion = secretVersion ?: throw PulumiNullFieldException("secretVersion"),
        subscriptionId = subscriptionId ?: throw PulumiNullFieldException("subscriptionId"),
        typeName = typeName ?: throw PulumiNullFieldException("typeName"),
        vaultName = vaultName ?: throw PulumiNullFieldException("vaultName"),
    )
}
